# Changelog

<!--next-version-placeholder-->

## v1.5.5 (2023-04-21)
### Fix
* Shebang for version 3 env ([`57d4c92`](https://github.com/Stephen-RA-King/pynball/commit/57d4c927521b73c715f5f574fe208b2f9966f878))

### Documentation
* Update email link ([`39fba7a`](https://github.com/Stephen-RA-King/pynball/commit/39fba7adc7058d786735e65daab3f8c7d979aaee))
* Update email address ([`736bb43`](https://github.com/Stephen-RA-King/pynball/commit/736bb432ab7501c58c9bab0813b560e6316cae22))

## v1.5.4 (2023-04-17)
### Fix
* File open encoding error ([`4304034`](https://github.com/Stephen-RA-King/pynball/commit/4304034b56d81cb34ffce552294a20a07fd55ea7))

### Documentation
* Rename base cookiecutter ([`9db5538`](https://github.com/Stephen-RA-King/pynball/commit/9db5538bfecb24210b138997f4efaeb7f3ffef34))
* Update meta ([`5275172`](https://github.com/Stephen-RA-King/pynball/commit/52751725028692807284dc65ac8101781bd30e50))
* Add pre-coomit.ci badge and docs sections ([`71ef0a6`](https://github.com/Stephen-RA-King/pynball/commit/71ef0a654672246a7db13b9e038dbf87c8d74c36))
* Correct type ([`5e350d2`](https://github.com/Stephen-RA-King/pynball/commit/5e350d27199ba2d80f86eb23a02edbf34249125a))

## v1.5.3 (2023-04-09)
### Fix
* Missing url links ([`c7209ee`](https://github.com/Stephen-RA-King/pynball/commit/c7209eeeb1e09ea8cc35049d5d7deabd94104cc1))

## v1.5.2 (2023-04-08)
### Documentation
* Add mnissing docstrings to functions ([`d19176f`](https://github.com/Stephen-RA-King/pynball/commit/d19176f36d3abe491f006757600bc87a885bbb20))
* Update readme with test results & coverage ([`cad0b5e`](https://github.com/Stephen-RA-King/pynball/commit/cad0b5e8724936f652f3fe2a83c6f80173a129be))

## v1.5.1 (2023-03-14)
### Fix
* Reverse last commit ([`ed7130b`](https://github.com/Stephen-RA-King/pynball/commit/ed7130bd4ab127362c7f4b3dfca797dd28f06814))

## v1.5.0 (2023-03-13)
### Feature
* Add automatic shell restart ([`b02d031`](https://github.com/Stephen-RA-King/pynball/commit/b02d031680359b9104eca27fc6e570c9386b5329))
* Add mvproject feature ([`165ecdd`](https://github.com/Stephen-RA-King/pynball/commit/165ecdd77d329d430ee143780709e7467e99ef35))
* Add -n option for mkproject ([`dd57c50`](https://github.com/Stephen-RA-King/pynball/commit/dd57c50cd70555a1b4e1eba0f9e1c69b30ed6bff))
* Add venv renaming function ([`df2e727`](https://github.com/Stephen-RA-King/pynball/commit/df2e7275296885b991ae247a9c3fd6ee2e67de44))

### Fix
* Imports and docstrintgs ([`c87c3b8`](https://github.com/Stephen-RA-King/pynball/commit/c87c3b8981b2ff6eeef4d038102f065c572adb9e))
* Libmagic import error ([`a00fb7b`](https://github.com/Stephen-RA-King/pynball/commit/a00fb7b9656eea1737bd0bab280eded7c11c541c))
* Make rmproject warning more descriptive ([`e0b14c2`](https://github.com/Stephen-RA-King/pynball/commit/e0b14c2f870c83d41cc190b1548d4e8c2c10f8c3))
* Change test order for mvproject function ([`e87dabc`](https://github.com/Stephen-RA-King/pynball/commit/e87dabc89d949b1be9a6eb74616ec24390e4c54c))
* Add exception handling for mvproject ([`3265299`](https://github.com/Stephen-RA-King/pynball/commit/3265299ee5da6f3781d8fa3c070d38bd28bcc384))
* Error in entrypoint ([`2e95fb1`](https://github.com/Stephen-RA-King/pynball/commit/2e95fb141cda3645135462b160d3696f1be3d5aa))
* Tests.yml - run tests on windows only ([`43adc6e`](https://github.com/Stephen-RA-King/pynball/commit/43adc6ed5c4c6d9a9aaf152086e9ed5d02af25c1))
* Add badges ([`8fc7318`](https://github.com/Stephen-RA-King/pynball/commit/8fc73182ad161b3ff1865a5e1ea663ab9a38645e))
* Add sphinx requirements file ([`55ad58a`](https://github.com/Stephen-RA-King/pynball/commit/55ad58af6a62cbf937ac3c73e62c7a23be62023d))
* Update uri link ([`764ad41`](https://github.com/Stephen-RA-King/pynball/commit/764ad4117abbf5c3dc10d9f6cdc4eb37e8d9f59d))
* Refresh project support files ([`2940049`](https://github.com/Stephen-RA-King/pynball/commit/2940049e9745b1cb603331db78d947f2f0f378be))
* Spelling ([`4551e5d`](https://github.com/Stephen-RA-King/pynball/commit/4551e5db3145f383aa3677b0cf550e96464c05b8))
* Correct spelling error ([`143151b`](https://github.com/Stephen-RA-King/pynball/commit/143151baac9d735c381f7c324816b1fcc2788154))
* Consolidate error messages ([`52a106c`](https://github.com/Stephen-RA-King/pynball/commit/52a106c757bc12d507b13a1ff673b70f783df73e))
* Change None to Path object ([`28bf8ba`](https://github.com/Stephen-RA-King/pynball/commit/28bf8ba3d5cc77346e9c6dae883ce6b8778e247e))

### Documentation
* Update mata email address ([`bd2e9b5`](https://github.com/Stephen-RA-King/pynball/commit/bd2e9b50f5fed8f45302f0a0b0463e31f6ba5fc9))
* Update supported python versions ([`ea90036`](https://github.com/Stephen-RA-King/pynball/commit/ea90036c68ad825894d8382278801b8bd588dd54))

## v1.4.0 (2023-03-13)
### Feature
* Add automatic shell restart ([`b02d031`](https://github.com/Stephen-RA-King/pynball/commit/b02d031680359b9104eca27fc6e570c9386b5329))

### Documentation
* Update mata email address ([`bd2e9b5`](https://github.com/Stephen-RA-King/pynball/commit/bd2e9b50f5fed8f45302f0a0b0463e31f6ba5fc9))
* Update supported python versions ([`ea90036`](https://github.com/Stephen-RA-King/pynball/commit/ea90036c68ad825894d8382278801b8bd588dd54))


## v1.3.1 (2022-10-30)
### Fix
* Imports and docstrintgs ([`c87c3b8`](https://github.com/Stephen-RA-King/pynball/commit/c87c3b8981b2ff6eeef4d038102f065c572adb9e))


## v1.2.1 (2022-09-30)
### Fix
* Libmagic import error ([`a00fb7b`](https://github.com/Stephen-RA-King/pynball/commit/a00fb7b9656eea1737bd0bab280eded7c11c541c))

## v1.2.0 (2022-09-29)
### Feature
* Add mvproject feature ([`165ecdd`](https://github.com/Stephen-RA-King/pynball/commit/165ecdd77d329d430ee143780709e7467e99ef35))
* Add -n option for mkproject ([`dd57c50`](https://github.com/Stephen-RA-King/pynball/commit/dd57c50cd70555a1b4e1eba0f9e1c69b30ed6bff))

## v1.1.5 (2022-07-22)


## v1.1.4 (2022-07-17)
### Fix
* Make rmproject warning more descriptive ([`e0b14c2`](https://github.com/Stephen-RA-King/pynball/commit/e0b14c2f870c83d41cc190b1548d4e8c2c10f8c3))

## v1.1.3 (2022-07-17)
### Fix
* Change test order for mvproject function ([`e87dabc`](https://github.com/Stephen-RA-King/pynball/commit/e87dabc89d949b1be9a6eb74616ec24390e4c54c))

## v1.1.2 (2022-07-17)
### Fix
* Add exception handling for mvproject ([`3265299`](https://github.com/Stephen-RA-King/pynball/commit/3265299ee5da6f3781d8fa3c070d38bd28bcc384))

## v1.1.1 (2022-07-17)
### Fix
* Error in entrypoint ([`2e95fb1`](https://github.com/Stephen-RA-King/pynball/commit/2e95fb141cda3645135462b160d3696f1be3d5aa))

## v1.1.0 (2022-07-17)
### Feature
* Add venv renaming function ([`df2e727`](https://github.com/Stephen-RA-King/pynball/commit/df2e7275296885b991ae247a9c3fd6ee2e67de44))

### Fix
* Tests.yml - run tests on windows only ([`43adc6e`](https://github.com/Stephen-RA-King/pynball/commit/43adc6ed5c4c6d9a9aaf152086e9ed5d02af25c1))
* Add badges ([`8fc7318`](https://github.com/Stephen-RA-King/pynball/commit/8fc73182ad161b3ff1865a5e1ea663ab9a38645e))
* Add sphinx requirements file ([`55ad58a`](https://github.com/Stephen-RA-King/pynball/commit/55ad58af6a62cbf937ac3c73e62c7a23be62023d))

## v1.0.3 (2022-05-31)
### Fix
* Update uri link ([`764ad41`](https://github.com/Stephen-RA-King/pynball/commit/764ad4117abbf5c3dc10d9f6cdc4eb37e8d9f59d))

## 1.0.2 (2022-05-31)

### First Release of 'pynball'



<!-- Markdown link & img dfn's -->

[github](https://github.com/Stephen-RA-King/pynball)
